
# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


import os.path

readme = ''
here = os.path.abspath(os.path.dirname(__file__))
readme_path = os.path.join(here, 'README.rst')
if os.path.exists(readme_path):
    with open(readme_path, 'rb') as stream:
        readme = stream.read().decode('utf8')


setup(
    long_description=readme,
    name='aws-service-catalog-puppet',
    version='0.76.3',
    description='Making it easier to deploy ServiceCatalog products',
    python_requires='>=3.7',
    project_urls={"homepage": "https://github.com/awslabs/aws-service-catalog-puppet-framework", "repository": "https://github.com/awslabs/aws-service-catalog-puppet-framework"},
    author='Eamonn Faherty',
    author_email='aws-service-catalog-tools@amazon.com',
    classifiers=['Development Status :: 5 - Production/Stable', 'Intended Audience :: Developers', 'Programming Language :: Python :: 3', 'License :: OSI Approved :: Apache Software License', 'Operating System :: OS Independent', 'Natural Language :: English'],
    entry_points={"console_scripts": ["servicecatalog-puppet = servicecatalog_puppet.cli:cli"]},
    packages=['servicecatalog_puppet', 'servicecatalog_puppet.workflow'],
    package_dir={"": "."},
    package_data={"servicecatalog_puppet": ["*.yaml", "data/account-vending/*.json", "data/manifest_utils/*.yaml", "data/manifest_utils/accounts/*.yaml", "data/manifest_utils/tags/*.yaml", "data/manifest_utils_for_spoke_local_portfolios/*.yaml", "manifests/*.yaml", "templates/*.j2"]},
    install_requires=['better-boto==0.28.0', 'boto3', 'cfn-flip==1.2.3', 'click==7.0', 'colorclass==2.2.0', 'jinja2==2.10.1', 'luigi==2.8.9', 'progressbar==2.5', 'psutil==5.7.0', 'pykwalify==1.7.0', 'pyyaml==5.1', 'requests==2.22.0', 'terminaltables==3.1.0'],
    extras_require={"dev": ["behave==1.*,>=1.2.6", "codecov==2.*,>=2.1.7", "pylint==2.*,>=2.5.3", "pytest>=5.3.2", "pytest-cov==2.*,>=2.10.0", "pytest-datadir==1.*,>=1.3.1", "pytest-mock==3.*,>=3.1.1"]},
)
